@@ -233,7 +233,7 @@ def plot_stacked_bars(
     height: int = 500,
     width: int = 2000,
     title: str = None,
-    renderer: Literal["png", "svg", None] = "png",
+    renderer: Literal["png", "svg", None] = None,
     caption: str = None,
     sort_values: bool = False,
     sort_values_index: bool = False,
@@ -375,19 +375,24 @@ def plot_stacked_bars(
     caption = _set_caption(caption)
 
     # * after grouping add cols for pct and formatting
-    df["cnt_pct_all_only"] = df["value"].apply(lambda x: f"{(x / n) * 100:.{precision}f}%")
-    df["cnt_pct_bar_only"] = (df["value"] / bar_totals * 100).apply(lambda x: f"{x:.{precision}f}%")
+    df["cnt_pct_all_only"] = (df["value"] / n * 100).apply(lambda x: f"{(x):.{precision}f}%")
+    df["cnt_pct_bar_only"] = (df["value"] / bar_totals * 100).apply(lambda x: f"{(x):.{precision}f}%")
 
     # * format output
     df["cnt_str"] = df["value"].apply(lambda x: f"{x:_.{precision}f}")
 
     divider2 = "<br>" if orientation == "v" else " "
     
+    # Modify this section
     df["cnt_pct_all_str"] = df.apply(
-        lambda row: f"{row['cnt_str']}{divider2}({row['cnt_pct_all_only']})", axis=1
+        lambda row: f"{row['cnt_str']}{divider2}({row['cnt_pct_all_only']})"
+        if (row["value"] / n * 100) >= 5 else row["cnt_str"],
+        axis=1
     )
     df["cnt_pct_bar_str"] = df.apply(
-        lambda row: f"{row['cnt_str']}{divider2}({row['cnt_pct_bar_only']})", axis=1
+        lambda row: f"{row['cnt_str']}{divider2}({row['cnt_pct_bar_only']})"
+        if (row["value"] / bar_totals.loc[row.name] * 100) >= 5 else row["cnt_str"],
+        axis=1
     )
 
     text_to_show = "cnt_str"
@@ -499,7 +504,7 @@ def plot_stacked_bars(
         fig.write_image(Path(png_path).as_posix())
 
     fig.show(
-        renderer=renderer,
+        renderer=renderer or os.getenv("RENDERER"),
         width=width,
         height=height,
     )
@@ -521,7 +526,7 @@ def plot_bars(
     use_ci: bool = False,
     ci_agg: Literal["mean", "median"] = "mean",
     precision: int = 0,
-    renderer: Literal["png", "svg", None] = "png",
+    renderer: Literal["png", "svg", None] = None,
     png_path: Path | str = None,
 ) -> None:
     """
@@ -548,7 +553,7 @@ def plot_bars(
         - enforces nomalize=False
         - enforces dropna=True
     - precision: An integer indicating the number of decimal places to round the values to. Default is 0.
-    - renderer: A string indicating the renderer to use for displaying the chart. It can be "png", "svg", or None. Default is "png".
+    - renderer: A string indicating the renderer to use for displaying the chart. It can be "png", "svg", or None. Default is None.
     - png_path (Path | str, optional): The path to save the image as a png file. Defaults to None.
 
     Returns: None
@@ -780,7 +785,7 @@ def plot_bars(
 
     # * set axis title
     _fig.show(
-        renderer,
+        renderer=renderer or os.getenv("RENDERER"),
         width=width,
         height=height,
     )
@@ -804,7 +809,7 @@ def plot_histogram(
     width: int = 1600,
     text_auto: bool = True,
     barmode: Literal["group", "overlay", "relative"] = "relative",
-    renderer: Literal["png", "svg", None] = "png",
+    renderer: Literal["png", "svg", None] = None,
     caption: str = None,
     title: str = None,
     png_path: Path | str = None,
@@ -825,7 +830,7 @@ def plot_histogram(
         width (int): The width of the plot. Default is 1600.
         text_auto (bool): Whether to automatically display text on the plot. Default is True.
         barmode (Literal["group", "overlay", "relative"]): The mode for the bars in the histogram. Default is "relative".
-        renderer (Literal["png", "svg", None]): The renderer for displaying the plot. Default is "png".
+        renderer (Literal["png", "svg", None]): The renderer for displaying the plot. Default is None.
         caption (str): The caption for the plot. Default is None.
         title (str): The title of the plot. Default is None.
         png_path (Path | str, optional): The path to save the image as a png file. Defaults to None.
@@ -1003,7 +1008,7 @@ def plot_box(
     x_max: float = None,
     use_log: bool = False,
     png_path: Path | str = None,
-    renderer: Literal["png", "svg", None] = "png",
+    renderer: Literal["png", "svg", None] = None,
 ) -> None:
     """
     Plots a horizontal box plot for the given pandas Series.
@@ -1023,7 +1028,7 @@ def plot_box(
         x_max: The maximum value for the x-axis scale (max and min must be set).
         use_log: Use logarithmic scale for the axis.
         png_path (Path | str, optional): The path to save the image as a png file. Defaults to None.
-        renderer (Literal["png", "svg", None], optional): The renderer to use for saving the image. Defaults to "png".
+        renderer (Literal["png", "svg", None], optional): The renderer to use for saving the image. Defaults to None.
 
     Returns: None
     """
@@ -1138,7 +1143,7 @@ def plot_box(
         )
 
     fig.show(
-        renderer=renderer,
+        renderer=renderer or os.getenv("RENDERER"),
         width=width,
         height=height,
     )
@@ -1167,7 +1172,7 @@ def plot_boxes(
     use_log: bool = False,
     box_width: float = 0.5,
     png_path: Path | str = None,
-    renderer: Literal["png", "svg", None] = "png",
+    renderer: Literal["png", "svg", None] = None,
 ) -> None:
     """
     [Experimental] Plot vertical boxes for each unique item in the DataFrame and add annotations for statistics.
@@ -1183,7 +1188,7 @@ def plot_boxes(
         summary (bool): Whether to add a summary to the plot.
         use_log (bool): Whether to use logarithmic scale for the plot (cannot show negative values).
         png_path (Path | str, optional): The path to save the image as a png file. Defaults to None.
-        renderer (Literal["png", "svg", None], optional): The renderer to use for saving the image. Defaults to "png".
+        renderer (Literal["png", "svg", None], optional): The renderer to use for saving the image. Defaults to None.
 
     Returns: None
     """
@@ -1304,7 +1309,7 @@ def plot_boxes(
         marker=dict(size=5), width=box_width
     )  # Adjust width (default ~0.5)
 
-    fig.show(renderer=renderer, width=width, height=height)
+    fig.show(renderer=renderer or os.getenv("RENDERER"), width=width, height=height)
     if summary:
         # * sort df by first column
         print_summary(df=df.sort_values(df.columns[0]), precision=precision)
@@ -1326,7 +1331,7 @@ def plot_facet_stacked_bars(
     subplot_size: int = 300,
     color_palette: str = "Plotly",
     caption: str = "",
-    renderer: Optional[Literal["png", "svg"]] = "png",
+    renderer: Optional[Literal["png", "svg", None]] = "png",
     annotations: bool = False,
     precision: int = 0,
     png_path: Optional[Path] = None,
@@ -1517,7 +1522,7 @@ def plot_facet_stacked_bars(
         fig.write_image(str(png_path))
 
     fig.show(
-        renderer=renderer,
+        renderer=renderer or os.getenv("RENDERER"),
         width=subplot_size * subplots_per_row,
         height=subplot_size
         * (-(-len(aggregated_df["facet"].unique()) // subplots_per_row)),
@@ -1558,7 +1563,7 @@ def plot_sankey(
         exclude_overlap_event (bool): If True, only excludes the specific events that fall on the same date,
                                     retaining other non-overlapping events for that ID.
         renderer (str, optional): The renderer to use for displaying the plot. Options include
-                                'browser', 'notebook', 'json', 'png', 'svg', 'jpeg', 'webp', or 'pdf'.
+                                'browser', None, 'json', 'png', 'svg', 'jpeg', 'webp', or 'pdf'.
                                 If None, plotly's default renderer is used.
         show_start_node (bool): If True, adds a visual 'start' node and links all
                                 first events to it. This is useful for visualizing
@@ -1855,8 +1860,7 @@ def plot_sankey(
     )
 
     fig.update_layout(title_text=chart_title, font_size=font_size)
-    fig.show(renderer=renderer, width=width, height=height)
-
+    fig.show(renderer=renderer or os.getenv("RENDERER"), width=width, height=height)
 
 # * extend objects to enable chaining
 pd.DataFrame.plot_bars = plot_bars
